@@ -1,6 +1,6 @@
 from logging import getLogger
 
-from django.db.models import Sum, Value, Q
+from django.db.models import F, Sum, Value, Q
 from django.db.models.functions import Concat
 from django.utils import timezone
 
@@ -106,6 +106,7 @@ class AxesDatabaseHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         # This replaces null byte chars that crash saving failures.
@@ -156,19 +157,18 @@ class AxesDatabaseHandler(AbstractAxesHandler, AxesBaseHandler):
                 attempt.post_data = Concat("post_data", Value(separator + post_data))
                 attempt.http_accept = request.axes_http_accept
                 attempt.path_info = request.axes_path_info
-                attempt.failures_since_start += 1
+                attempt.failures_since_start = F("failures_since_start") + 1
                 attempt.attempt_time = request.axes_attempt_time
                 attempt.save()
 
                 log.warning(
-                    "AXES: Repeated login failure by %s. Count = %d of %d. Updated existing record in the database.",
+                    "AXES: Repeated login failure by %s. Updated existing record in the database.",
                     client_str,
-                    attempt.failures_since_start,
-                    get_failure_limit(request, credentials),
                 )
 
         # 3. or 4. database query: Calculate the current maximum failure number from the existing attempts
         failures_since_start = self.get_failures(request, credentials)
+        request.axes_failures_since_start = failures_since_start
 
         if (
             settings.AXES_LOCK_OUT_AT_FAILURE
@@ -203,6 +203,7 @@ class AxesDatabaseHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         log.info("AXES: Successful login by %s.", client_str)
@@ -243,6 +244,7 @@ class AxesDatabaseHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         log.info("AXES: Successful logout by %s.", client_str)
